@@ -142,7 +142,7 @@ class VisualizationFunctions:
     # MatPlotLib-powered figures
 
     @tryExcept
-    def makeHeatmapGeneExpressionPlot(self, df = None, genes = None, nameToAppend = 'heatmap', plotBy = 'cluster', figsize = (8, 4), convertGenes = False, dpi = 300, extension = 'png', **kwargs):
+    def makeHeatmapGeneExpressionPlot(self, df = None, genes = None, normalize = True, saveExcel = True, nameToAppend = 'heatmap', plotBy = 'cluster', figsize = (8, 4), convertGenes = False, dpi = 300, extension = 'png', **kwargs):
 
         '''Make heatmap gene expression plot from a provided gene expression matrix.
 
@@ -204,15 +204,19 @@ class VisualizationFunctions:
         df.columns = df.columns.get_level_values(plotBy)
         df.columns = list(zip(df.columns.values, counts.values[0]))
 
-        for i in range(df.shape[0]):
-            df.iloc[i,:] -= np.min(df.iloc[i,:])
-            df.iloc[i,:] /= np.max(df.iloc[i,:])
+        if normalize:
+            for i in range(df.shape[0]):
+                df.iloc[i,:] -= np.min(df.iloc[i,:])
+                df.iloc[i,:] /= np.max(df.iloc[i,:])
         
         #df = df.T.iloc[scipy.cluster.hierarchy.dendrogram(scipy.cluster.hierarchy.linkage(df.T, 'ward'), no_plot=True, get_leaves=True)['leaves']].T
         df = df.iloc[scipy.cluster.hierarchy.dendrogram(scipy.cluster.hierarchy.linkage(df, 'ward'), no_plot=True, get_leaves=True)['leaves']]
 
         df.insert(0, ('Mean', 'All'), means)
 
+        if saveExcel:
+            df.T.to_excel(os.path.join(self.saveDir, self.dataName + '_' + nameToAppend + '_genes_by_%s' % (plotBy) + '.xlsx'))
+
         fig, ax = plt.subplots(figsize=figsize)
 
         ax.imshow(df.T.values[1:,:], cmap='Blues', interpolation='None', aspect='auto', 
